# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-06 07:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0019_auto_20191106_1513'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='item_type',
            field=models.IntegerField(choices=[(1, '\u5b9e\u7269'), (2, '\u865a\u62df')], default=2, verbose_name='\u5546\u54c1\u7c7b\u578b'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='item',
            name='item_type',
            field=models.IntegerField(choices=[(1, '\u5b9e\u7269'), (2, '\u865a\u62df')], default=0, verbose_name='\u5546\u54c1\u7c7b\u578b'),
        ),
    ]
