# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-09 06:04
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_coin', '0008_auto_20181019_1557'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u5546\u54c1\u540d\u79f0')),
                ('coin', models.IntegerField(verbose_name='\u8d2d\u4e70\u9700\u8981')),
                ('pic', models.TextField(help_text='\u76ee\u524d\u4ec5\u652f\u6301\u7f51\u7edc\u56fe\u7247', null=True, verbose_name='\u5546\u54c1\u56fe\u7247\u7f51\u5740')),
                ('info', models.TextField(null=True, verbose_name='\u8be6\u60c5')),
                ('item_type', models.IntegerField(default=0, verbose_name='\u5546\u54c1\u7c7b\u578b')),
                ('stauts', models.IntegerField(default=0, verbose_name='\u5546\u54c1\u72b6\u6001')),
                ('edit_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': ['pk'],
                'db_table': 'bee_django_coin_item',
            },
        ),
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order_id', models.CharField(max_length=180)),
                ('item_id', models.IntegerField()),
                ('item_name', models.CharField(max_length=180)),
                ('item_count', models.IntegerField(default=0)),
                ('item_coin', models.IntegerField(default=0)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('status', models.IntegerField(default=1)),
                ('info', models.TextField(null=True, verbose_name='\u5907\u6ce8')),
                ('evaluate', models.IntegerField(null=True)),
                ('evaluate_info', models.TextField(null=True)),
                ('evaluate_datetime', models.DateTimeField(null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\u8d2d\u4e70\u4eba')),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_coin_order',
            },
        ),
    ]
