# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-18 07:08
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0006_auto_20181016_1717'),
    ]

    operations = [
        migrations.RenameField(
            model_name='othercoincount',
            old_name='other_type_id',
            new_name='coin_content_id',
        ),
    ]
