# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-22 05:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0014_item_url'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='url',
            field=models.URLField(blank=True, help_text='\u586b\u5199\u6b64\u9879\u540e\uff0c\u70b9\u51fb\u8be5\u5546\u54c1\u5219\u81ea\u52a8\u8df3\u8f6c\u5230\u94fe\u63a5\u5730\u5740\u3002', null=True, verbose_name='\u5546\u54c1\u94fe\u63a5'),
        ),
    ]
