# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-16 08:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0004_auto_20180620_1845'),
    ]

    operations = [
        migrations.CreateModel(
            name='OtherCoinCount',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('other_type', models.CharField(choices=[(1, '\u73ed\u7ea7\u5269\u4f59\u91d1\u5e01')], max_length=180, null=True)),
                ('other_type_id', models.IntegerField()),
                ('count', models.IntegerField(default=0)),
                ('update_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': ['pk'],
                'db_table': 'bee_django_coin_other_count',
            },
        ),
        migrations.AddField(
            model_name='usercoinrecord',
            name='coin_content_id',
            field=models.IntegerField(null=True),
        ),
    ]
