# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-09 06:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0010_auto_20181109_1415'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item',
            name='stauts',
        ),
        migrations.AddField(
            model_name='item',
            name='status',
            field=models.IntegerField(choices=[(1, '\u4e0a\u67b6'), (2, '\u4e0b\u67b6')], default=0, verbose_name='\u5546\u54c1\u72b6\u6001'),
        ),
        migrations.AlterField(
            model_name='item',
            name='item_type',
            field=models.IntegerField(choices=[(1, '\u5b9e\u7269'), (2, '\u62b5\u7528\u5238')], default=0, verbose_name='\u5546\u54c1\u7c7b\u578b'),
        ),
    ]
