{% extends "bee_django_coin/base.html" %}
{% load bee_django_coin_filter %}
{% block styles %}
    <style>

    </style>
{% endblock %}
{% block content %}
    <div class="text-center"><h3>{{ context_coin_name }}排行榜</h3></div>

    <hr style="margin: 10px auto;">

    {% for user_coin in user_list %}
        <div class="row">
            <div class="col-xs-1">{{ forloop.counter }}</div>
            <div class="col-xs-3">{{ user_coin.user|get_name_detail:False }}</div>
            <div class="col-xs-3">{{ user_coin.coin_count }}{{ context_coin_name }}</div>

        </div>

        <hr style="margin: 10px auto;">

    {% endfor %}
    {% include 'bee_django_coin/paginator.html' %}
{% endblock %}
{% block scripts %}
    <script>

    </script>
{% endblock %}