# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-12-27 07:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='cointype',
            name='identity',
            field=models.CharField(max_length=180, null=True, unique=True, verbose_name='\u6807\u8bc6\u7b26'),
        ),
    ]
