# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-20 07:42
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_coin', '0002_cointype_identity'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserCoinCount',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('coin_count', models.IntegerField(default=0)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-coin_count'],
                'db_table': 'bee_django_coin_rank_list',
            },
        ),
    ]
