# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-19 07:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0007_auto_20181018_1508'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='othercoincount',
            options={'ordering': ['pk'], 'permissions': (('add_teach_class_coin', '\u53ef\u4ee5\u53d1\u6240\u6559\u73ed\u7ea7M\u5e01'),)},
        ),
    ]
