# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-20 10:45
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0003_usercoincount'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cointype',
            options={'ordering': ['id'], 'permissions': (('can_manage_coin', '\u53ef\u4ee5\u8fdb\u5165M\u5e01\u7ba1\u7406\u9875'),)},
        ),
        migrations.AlterField(
            model_name='cointype',
            name='identity',
            field=models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, null=True, unique=True, verbose_name='\u6807\u8bc6\u7b26'),
        ),
        migrations.AlterField(
            model_name='usercoinrecord',
            name='coin',
            field=models.IntegerField(help_text='\u6263\u9664\u586b\u5165\u8d1f\u6570', verbose_name='\u6570\u91cf'),
        ),
        migrations.AlterField(
            model_name='usercoinrecord',
            name='coin_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_coin.CoinType', verbose_name='\u7c7b\u578b'),
        ),
    ]
