# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-16 09:17
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0005_auto_20181016_1619'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='othercoincount',
            name='other_type',
        ),
        migrations.AddField(
            model_name='othercoincount',
            name='coin_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_coin.CoinType', verbose_name='\u7c7b\u578b'),
        ),
    ]
