# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-06 07:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0018_auto_20191106_1513'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u5907\u6ce8'),
        ),
    ]
