# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-06 07:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0017_auto_20191106_1506'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='item_count',
            field=models.IntegerField(default=1, verbose_name='\u5546\u54c1\u6570\u91cf'),
        ),
    ]
