# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-06 07:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0020_auto_20191106_1516'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='deliver',
            field=models.TextField(blank=True, help_text='\u586b\u5199\u5feb\u9012\u5355\u53f7\u7b49\u4fe1\u606f', null=True, verbose_name='\u53d1\u8d27\u4fe1\u606f'),
        ),
    ]
