# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-09 06:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0009_item_order'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u8be6\u60c5'),
        ),
        migrations.AlterField(
            model_name='item',
            name='pic',
            field=models.TextField(blank=True, help_text='\u76ee\u524d\u4ec5\u652f\u6301\u7f51\u7edc\u56fe\u7247', null=True, verbose_name='\u5546\u54c1\u56fe\u7247\u7f51\u5740'),
        ),
    ]
