# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 12:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0015_auto_20181122_1337'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='item',
            options={'ordering': ['pk'], 'permissions': (('view_item_list', '\u67e5\u770b\u5546\u54c1\u5217\u8868'),)},
        ),
        migrations.AlterModelOptions(
            name='order',
            options={'ordering': ['-created_at'], 'permissions': (('view_order_list', '\u67e5\u770b\u8ba2\u5355\u5217\u8868'),)},
        ),
    ]
