{% extends "bee_django_coin/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
    <form method="post">
        {% csrf_token %}

        {% bootstrap_form form %}
        {% bootstrap_button '提交' %}
    </form>

{% endblock %}

{% block scripts %}
    <script>

    </script>
{% endblock %}