<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>
<div class="nav">
    <a href="{% url 'bee_django_coin:coin_type_list' %}">类型管理</a> |
    <a href="{% url 'bee_django_coin:coin_record_add' user_id=request.user.id %}">发{{ context_coin_name }}</a> |
    <a href="{% url 'bee_django_coin:other_record_add' coin_identity='user_class' coin_content_id=1 %}">发班级{{ context_coin_name }}</a>
    |
    <a href="{% url 'bee_django_coin:other_record_list' coin_identity='user_class' coin_content_id=1 %}">班级{{ context_coin_name }}记录</a>
    |
    <a href="{% url 'bee_django_coin:user_record_list' user_id=request.user.id %}">发放记录</a> |
    <a href="{% url 'bee_django_coin:user_rank_list' %}">{{ context_coin_name }}排行</a> |

    <a href="{% url 'bee_django_coin:item_custom_list' %}">用户商城首页(test)</a> |
    {% if perms.bee_django_coin.view_item_list %}
        <a href="{% url 'bee_django_coin:item_list' %}">商品列表</a> |
    {% endif %}

    {% if perms.bee_django_coin.view_order_list %}
        <a href="{% url 'bee_django_coin:order_list' %}">订单列表</a> |
    {% endif %}
    {% if perms.bee_django_coin.view_order_list or perms.bee_django_coin.view_item_list %}
        <a href="https://note.youdao.com/ynoteshare1/index.html?id=05ffd4a7bfc7309cad7edc68faf25d6d&type=notebook"
           target="_blank">帮助文档</a> |
    {% endif %}

</div>
