{% extends "bee_django_coin/base.html" %}
{% load bee_django_coin_filter %}
{% block content %}
    <div class="col-md-12">
        <h4>订单详情</h4>


        <table class="table">
            <tr>
                <td class="col-xs-3">订单编号</td>
                <td>{{ order.order_id }}</td>
            </tr>
            <tr>
                <td>用户</td>
                <td>{{ order.user }}</td>
            </tr>
            <tr>
                <td>商品类型</td>
                <td>{{ order.get_item_type }}</td>
            </tr>
            <tr>
                <td>商品名称</td>
                <td>{{ order.item_name }}</td>
            </tr>
            <tr>
                <td>数量</td>
                <td>{{ order.item_count }}</td>
            </tr>
            <tr>
                <td>价格共计</td>
                <td>{{ order.item_coin }}{{ context_coin_name }}</td>
            </tr>
            <tr>
                <td>下单时间</td>
                <td>{{ order.created_at }}</td>
            </tr>
            <tr>
                <td>当前状态</td>
                <td>{{ order.get_status }}</td>
            </tr>
            {% if order.deliver %}
                <tr>
                    <td>发货信息</td>
                    <td>{{ order.deliver }}</td>
                </tr>
            {% endif %}
            <tr>
                <td>详情</td>
                <td>{{ order.info|default:""|safe }}</td>
            </tr>

        </table>
    </div>




{% endblock %}

{% block scripts %}
    <script type="text/javascript">
        $(document).ready(function () {

        })
    </script>
{% endblock %}
